pub enum EventHeaderState {
Full,
TimestampOnly,
Hidden,
}Expand description
The state of the header of an event in the room history.
Variants
Full
The full header is displayed, with an avatar, a sender name and the timestamp.
TimestampOnly
Only the timestamp is displayed.
Hidden
The header is hidden.
Implementations
Sourceimpl EventHeaderState
impl EventHeaderState
Sourcefn register_enum() -> Type
fn register_enum() -> Type
Registers the enum only once.